@@ -1,7 +1,7 @@
 """Utilizario de funciones usadas en los procesos de robotizacion
    con Python."""
 
-__version__ = "1.22"
+__version__ = "1.23"
 __author__ = "Jonathan Bolo"
 
 import os, re, shutil
@@ -136,13 +136,15 @@ def upload_file_sftp(filename, destine_path="", credentials={}):
                 if not flag_exists:
                     raise Exception("No se encontró coincidencias para: " + filename)
 
-def makedir_sftp(sftp_path="", credentials={}, recursive = False):
+def makedir_sftp(sftp_path="", credentials={}, recursive = False, mode=755):
     """Funcion que crea directorios en un SFTP
 
     Args:
         sftp_path (str, optional): Ruta remoto a crear. Defaults to "".
         credentials (dict, optional): Diccionario con credenciales. Defaults to {}.
-        recursive (bool, optional): Flag que permite crear directorios recursivamente. Defaults to False.
+        recursive (bool, optional): Flag que permite crear directorios
+                                    recursivamente. Defaults to False.
+        mode (int, optional): Permisos de directorio. Defaults to 755.
     """
     
     import paramiko
@@ -185,7 +187,7 @@ def makedir_sftp(sftp_path="", credentials={}, recursive = False):
 
                     if not exists:
                         log.info("Creando directorio recursivo:" + abs_path)
-                        server.mkdir(abs_path, mode=755)
+                        server.mkdir(abs_path, mode)
                     else:
                         log.info("Directorio recursivo ya existe:" + abs_path)
                         continue
@@ -200,7 +202,7 @@ def makedir_sftp(sftp_path="", credentials={}, recursive = False):
 
                 if not exists:
                     log.info("Creando directorio no recursivo:" + sftp_path)
-                    server.mkdir(sftp_path, mode=755)
+                    server.mkdir(sftp_path, mode)
                 else:
                     log.info("Directorio no recursivo ya existe:" + sftp_path)
 
@@ -336,8 +338,11 @@ def download_file_sftp(filename="", destine_path="", credentials={}, flag_remove
                 log.debug ("Lista SFTP: "+ str(dir_list))
             
                 
-                log.debug("Buscando coincidencias con: " + filename_remoto_comodin)
+                log.debug("Buscando coincidencias con: " +
+                          filename_remoto_comodin)
 
+                flag_exists = False
+                
                 for file in dir_list:
                     
                     if fnmatch.fnmatch(file, filename_remoto_comodin):
